summaryrefslogtreecommitdiff
path: root/extensions/SyntaxHighlight_GeSHi/maintenance
diff options
context:
space:
mode:
authorPierre Schmitz <pierre@archlinux.de>2015-12-17 09:15:42 +0100
committerPierre Schmitz <pierre@archlinux.de>2015-12-17 09:44:51 +0100
commita1789ddde42033f1b05cc4929491214ee6e79383 (patch)
tree63615735c4ddffaaabf2428946bb26f90899f7bf /extensions/SyntaxHighlight_GeSHi/maintenance
parent9e06a62f265e3a2aaabecc598d4bc617e06fa32d (diff)
Update to MediaWiki 1.26.0
Diffstat (limited to 'extensions/SyntaxHighlight_GeSHi/maintenance')
-rw-r--r--extensions/SyntaxHighlight_GeSHi/maintenance/updateCSS.php54
-rw-r--r--extensions/SyntaxHighlight_GeSHi/maintenance/updateLexerList.php (renamed from extensions/SyntaxHighlight_GeSHi/maintenance/updateLanguageList.php)40
2 files changed, 77 insertions, 17 deletions
diff --git a/extensions/SyntaxHighlight_GeSHi/maintenance/updateCSS.php b/extensions/SyntaxHighlight_GeSHi/maintenance/updateCSS.php
new file mode 100644
index 00000000..a3c0c817
--- /dev/null
+++ b/extensions/SyntaxHighlight_GeSHi/maintenance/updateCSS.php
@@ -0,0 +1,54 @@
+<?php
+/**
+ * Script to update Pygments CSS
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * http://www.gnu.org/copyleft/gpl.html
+ *
+ * @file
+ * @author Ori Livneh <ori@wikimedia.org>
+ * @ingroup Maintenance
+ */
+
+use KzykHys\Pygments\Pygments;
+
+$IP = getenv( 'MW_INSTALL_PATH' ) ?: __DIR__ . '/../../..';
+
+require_once "$IP/maintenance/Maintenance.php";
+
+class UpdateCSS extends Maintenance {
+
+ public function __construct() {
+ parent::__construct();
+ $this->addDescription( 'Generate CSS code for SyntaxHighlight_GeSHi' );
+ }
+
+ public function execute() {
+ global $wgPygmentizePath;
+
+ $target = __DIR__ . '/../modules/pygments.generated.css';
+ $pygments = new Pygments( $wgPygmentizePath );
+ $css = "/* Stylesheet generated by updateCSS.php */\n";
+ $css .= $pygments->getCss( 'default', '.' . SyntaxHighlight_GeSHi::HIGHLIGHT_CSS_CLASS );
+ if ( file_put_contents( $target, $css ) === false ) {
+ $this->output( "Failed to write to {$target}\n" );
+ } else {
+ $this->output( 'CSS written to ' . realpath( $target ) . "\n" );
+ }
+ }
+}
+
+$maintClass = "UpdateCSS";
+require_once RUN_MAINTENANCE_IF_MAIN;
diff --git a/extensions/SyntaxHighlight_GeSHi/maintenance/updateLanguageList.php b/extensions/SyntaxHighlight_GeSHi/maintenance/updateLexerList.php
index 6e9feb33..75beb9b5 100644
--- a/extensions/SyntaxHighlight_GeSHi/maintenance/updateLanguageList.php
+++ b/extensions/SyntaxHighlight_GeSHi/maintenance/updateLexerList.php
@@ -1,6 +1,6 @@
<?php
/**
* Script to update list of supported languages.
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
@@ -22,33 +22,39 @@
* @ingroup Maintenance
*/
+use KzykHys\Pygments\Pygments;
+
$IP = getenv( 'MW_INSTALL_PATH' ) ?: __DIR__ . '/../../..';
require_once "$IP/maintenance/Maintenance.php";
-require_once __DIR__ . "/../geshi/geshi.php";
class UpdateLanguageList extends Maintenance {
public function __construct() {
parent::__construct();
- $this->addDescription( 'Update list of languages supported by SyntaxHighlight_GeSHi' );
+ $this->addDescription( 'Update list of lexers supported by SyntaxHighlight_GeSHi' );
}
public function execute() {
- global $IP;
-
- $geshi = new GeSHi;
- $header = '// Generated by ' . basename( __FILE__ ) . ' on ' . date( DATE_RFC2822 ) . "\n";
- $langs = array_values( array_filter( $geshi->get_supported_languages( false ), 'ctype_alnum' ) );
- sort( $langs );
- $replace = array( '[' => "array(\n\t", ']' => "\n);\n", '",' => "\",\n\t" );
- $code = "<?php\n" .
- $header .
- "global \$wgGeSHiSupportedLanguages;\n" .
- '$wgGeSHiSupportedLanguages = ' . strtr( json_encode( $langs ), $replace );
- file_put_contents( __DIR__ . '/../SyntaxHighlight_GeSHi.langs.php', $code );
- $this->output( "Updated language list written to SyntaxHighlight_GeSHi.langs.php\n" );
+ global $wgPygmentizePath;
+
+ function lang_filter( $val ) {
+ return preg_match( '/^[a-zA-Z0-9\-_]+$/', $val );
+ }
+
+ $header = '// Generated by ' . basename( __FILE__ ) . "\n\n";
+
+ $pygments = new Pygments( $wgPygmentizePath );
+ $lexers = array_keys( $pygments->getLexers() );
+ sort( $lexers );
+
+ $code = "<?php\n" . $header . 'return ' . var_export( $lexers, true ) . ";\n";
+ $code = preg_replace( '/(\d+ \=\>| (?=\())/i', '', $code );
+ $code = preg_replace( "/^ +/m", "\t", $code );
+
+ file_put_contents( __DIR__ . '/../SyntaxHighlight_GeSHi.lexers.php', $code );
+ $this->output( "Updated language list written to SyntaxHighlight_GeSHi.lexers.php\n" );
}
}
$maintClass = "UpdateLanguageList";
-require_once( RUN_MAINTENANCE_IF_MAIN );
+require_once ( RUN_MAINTENANCE_IF_MAIN );
@@ -1,6 +1,6 @@
<?php
/**
- * Script to update list of supported languages.
+ * Script to update list of supported lexers.
*
* This program is free software; you can redistribute it and/or modify